/**
 * Touche Espace = Pause <br>
 * Clic souris dans la fenêtre d'abord <br> <br>
 * D'apres "LinearAverages" by Damien Di Fede. <br>
 * "This sketch demonstrates how to use the averaging abilities of the FFT. <br> 
 * linearly spaced averages are requested and then those are drawn as rectangles." <br>
 * <br>
 * Voir: Processing -> Menu File -> Examples...-> Libraries -> Minim Audio <br>
 * Voir:  <a href=http://processing.org/learning/library/linearaverages.html> http://processing.org/learning/library/linearaverages.html</a>
 */

import ddf.minim.analysis.*;  // Pour FFT
import ddf.minim.*;           // Pour AudioPlayer

String NomFichierAudio     = "jeunessechalette2.mp3";
int Average                = 256;
boolean ToucheEspace       = false;
// Choisir ligne 37 ou 42 -> fréquences Lin ou Log

Minim minim;
AudioPlayer MonPlayer;
FFT Mafft;

void setup() {
  size(400, 300);  // "The size() function must be the first line in setup()"
  // size(1024, 300); // pour voir tout le spectre
  minim = new Minim(this);
  MonPlayer = minim.loadFile(NomFichierAudio, 2048);
  MonPlayer.loop(); // Fichier Audio joué en boucle
  println("bufferSize = " + MonPlayer.bufferSize() + "  sampleRate = " + MonPlayer.sampleRate() );

  // create an FFT object that has a time-domain buffer the same size as MonPlayer's sample buffer
  // the size of the spectrum will be 1024
  // if MonPlayer.bufferSize = 2048 
  Mafft = new FFT(MonPlayer.bufferSize(), MonPlayer.sampleRate());
  Mafft.window(FFT.HAMMING);
  Mafft.linAverages(Average);

  // calculate averages based on a miminum octave width of 22 Hz
  // split each octave into three bands
  // this should result in 30 averages
  // Mafft.logAverages(22, 3);

  rectMode(CORNERS);
  noStroke();   // Essayer de supprimer...
}


void draw() {
  if (! ToucheEspace) {
    fill(0, 10);  // fill(gray, alpha) Couleur du rect de la taille de la fenetre
    rect(0, 0, width, height);

    fill(255, 30); //stroke(gray, alpha) couleur des "rect" qui suivent
    // perform a forward FFT on the samples in MonPlayer's left buffer
    // note that if MonPlayer were a MONO file, this would be the same as using MonPlayer.right or MonPlayer.left
    Mafft.forward(MonPlayer.mix);
    int w = int(Mafft.specSize()/Average);
    for (int i = 0; i <  min(Mafft.avgSize(), width / w); i++) {
      // draw a rectangle for each average
      // multiply the value by 5
      rect(i*w, height, i*w + w, height - Mafft.getAvg(i)*5);
    }
  }
}


void keyPressed() {
  // println("key = " + key);
  if (key == ' ') {         // barre d'espace
    ToucheEspace = ! ToucheEspace;
    if (ToucheEspace) MonPlayer.pause();
    else MonPlayer.loop(); // Fichier Audio joué en boucle
  }
}


void stop() {
  // always close Minim audio classes when you finish with them
  MonPlayer.close();
  minim.stop();
  super.stop();
}

